{% ckan_extends %}

{% if fields is not defined %}{% set fields = c.fields %}{% endif %}


{% block search_input %}
     {{ super() }}
     {% if include_children_option %}
       {{ form.checkbox('include_children', label="Include Sub-Organizations", checked=(h.is_include_children_selected()), value=True, error=error) }}
     {% endif %}
{% endblock %}
